==> ember-electron-3.1.0.tgz: package/lib/tasks/electron.js <==
'use strict';

const chalk = require('chalk');
const Task = require('ember-cli/lib/models/task');
const Watcher = require('ember-cli/lib/models/watcher');
const Builder = require('ember-cli/lib/models/builder');
const ExpressServer = require('ember-cli/lib/tasks/server/express-server');
const path = require('path');
const { electronProjectPath, emberBuildPath } = require('../utils/build-paths');
const debug = require('debug')('ember-electron:electron-task');
const { api } = require('../utils/forge-core');

class ElectronTask extends Task {
  async run(options) {
    let { ui } = this;

    ui.startProgress(chalk.green('Building'), chalk.green('.'));

    let builder = new Builder({
      ui,
      outputPath: emberBuildPath,
      environment: options.environment,
      project: this.project,
    });

    ui.writeLine(`Environment: ${options.environment}`);

    let watcher = new Watcher({
      ui,
      builder,
      analytics: this.analytics,
      options,
    });

    let expressServer = new ExpressServer({
      ui: this.ui,
      project: this.project,
      analytics: this.analytics,
      watcher,
      serverRoot: './server',
    });

    await Promise.all([expressServer.start(options), watcher]);
    await this._runElectron(builder, options);
  }

  async _runElectron(builder, { electronArgs = [] }) {
    if (electronArgs.length > 0) {
      this.ui.writeLine(
        chalk(`Starting Electron with args '${electronArgs.join(' ')}'...`)
      );
    } else {
      this.ui.writeLine(chalk('Starting Electron...'));
    }

    let proc = await api.start({
      dir: path.resolve(electronProjectPath),
      args: electronArgs,
    });

    proc.on('close', (code, signal) => {
      debug(`Electron closed with code: ${code} with signal: ${signal}`);
    });

    proc.on('disconnect', () => {
      debug('Electron disconnected.');
    });

    proc.on('error', (err) => {
      debug(`Error: ${err.stack || err}`);
    });

    proc.on('message', (message) => {
      debug(message);
    });

    await new Promise((resolve) => {
      proc.on('exit', () => {
        debug('Electron exited.');
        resolve();
      });
    });

    await builder.cleanup();
  }
}

module.exports = ElectronTask;

==> ember-electron-4.2.0.tgz: package/lib/tasks/electron.js <==
'use strict';

const chalk = require('chalk');
const Task = require('ember-cli/lib/models/task');
const Watcher = require('ember-cli/lib/models/watcher');
const Builder = require('ember-cli/lib/models/builder');
const ExpressServer = require('ember-cli/lib/tasks/server/express-server');
const path = require('path');
const { electronProjectPath, emberBuildPath } = require('../utils/build-paths');
const debug = require('debug')('ember-electron:electron-task');
const { api } = require('../utils/forge-core');

class ElectronTask extends Task {
  async run(options) {
    let { ui } = this;

    ui.startProgress(chalk.green('Building'), chalk.green('.'));

    let builder = new Builder({
      ui,
      outputPath: emberBuildPath,
      environment: options.environment,
      project: this.project,
    });

    ui.writeLine(`Environment: ${options.environment}`);

    let watcher;
    // The watcher API changed in ember-cli@4.9, so we need some compat code
    if (Watcher.build) {
      // ember-cli >= 4.9
      watcher = (
        await Watcher.build({
          ui,
          builder,
          analytics: this.analytics,
          options,
        })
      ).watcher;
    } else {
      // ember-cli < 4.9
      watcher = new Watcher({
        ui,
        builder,
        analytics: this.analytics,
        options,
      });
    }

    let expressServer = new ExpressServer({
      ui: this.ui,
      project: this.project,
      analytics: this.analytics,
      watcher,
      serverRoot: './server',
    });

    await Promise.all([expressServer.start(options), watcher]);
    await this._runElectron(builder, options);
  }

  async _runElectron(builder, { electronArgs = [] }) {
    if (electronArgs.length > 0) {
      this.ui.writeLine(
        chalk(`Starting Electron with args '${electronArgs.join(' ')}'...`)
      );
    } else {
      this.ui.writeLine(chalk('Starting Electron...'));
    }

    let proc = await api.start({
      dir: path.resolve(electronProjectPath),
      args: electronArgs,
    });

    proc.on('close', (code, signal) => {
      debug(`Electron closed with code: ${code} with signal: ${signal}`);
    });

    proc.on('disconnect', () => {
      debug('Electron disconnected.');
    });

    proc.on('error', (err) => {
      debug(`Error: ${err.stack || err}`);
    });

    proc.on('message', (message) => {
      debug(message);
    });

    await new Promise((resolve) => {
      proc.on('exit', () => {
        debug('Electron exited.');
        resolve();
      });
    });

    await builder.cleanup();
  }
}

module.exports = ElectronTask;
